VouchInitializer class

Constructors

VouchInitializer()
factory

Properties

branding ↔ Branding?
getter/setter pair
brandingController ↔ GetBrandingController
getter/setter pair
controller ↔ VouchSDKController
getter/setter pair
finishTapped bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isReady bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusController ↔ StatusController
getter/setter pair

Methods

init({required String brandToken, required String brandUrl, required String name, required String phone}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited